import javax.swing.*;
import java.awt.*;
import java.awt.geom.*;
import java.awt.image.*;

/**
 * <b>Programm:</b> WaveGradient<br>
 * <b>Copyright:</b> 2002 Andreas Gohr, Frank Schubert<br>
 * <b>License:</b> GPL2 or higher<br>
 * <br>
 * <b>Info:</b> paints the main diagram
 */
public class Painting extends Canvas{
  MonoWave _mw = null;
 
  /**
   * Constructor
   */
  public Painting(MonoWave mw) {
    _mw = mw;
  }

  /**
   * offscreen rendering
   */
  public void offpaint(Graphics g){
    Graphics2D g2d = (Graphics2D) g;
    g2d.setRenderingHint( RenderingHints.KEY_ANTIALIASING,
                          RenderingHints.VALUE_ANTIALIAS_ON);
    g2d.setBackground(Color.black);
    g2d.clearRect(0, 0, getWidth(), getHeight());

    g2d.setPaint(new WaveGradientPaint(_mw,Color.blue));

    Rectangle2D r = new Rectangle2D.Double(0,0,getWidth(),getHeight());
    g2d.fill(r);

    g2d.getTransform().setToIdentity(); //reset transformation
    g2d.setPaint(Color.white);

    // draw coordinates:
    for (int i=1; i< (int)(getWidth()/_mw.getScale())+1; i++){
      g2d.drawString(i+"s",(int)(i*_mw.getScale()),10);
    }
    for (int i=1; i< (int)(getWidth()/_mw.getScale()*(Math.PI/2))+1; i++){
      g2d.drawString((i/2.0f)+"Pi",7,(int)(i*(_mw.getScale()/(Math.PI/2))));
    }


    g2d.translate(getWidth()/2,getHeight()/2);  // set 0,0 to center

    g2d.setPaint(new Color(255,255,153,100));  //new paint (transparent yellow)
    Arc2D arc = new Arc2D.Double(-50.0,-50.0,100.0,100.0,0.0,_mw.getRotationDeg(),Arc2D.PIE);
    g2d.fill(arc);
    
  }


  /**
   * Overwrites original update and removes the screnn clearing as we use
   * doublebuffering by using offpaint()
   */
  public void update(Graphics g){
    paint(g);
  }
  
  /**
   * initializes the offscreenbuffer, calls offpaint() and paints the buffer
   * forces a repaint of the projections too.
   */
  public void paint(Graphics g){
    BufferedImage buffer;
    buffer =  (BufferedImage)createImage(getWidth(),getHeight());
    offpaint(buffer.getGraphics());

    g.drawImage(buffer,0,0,this);
    WaveGradientMain parent = (WaveGradientMain) getParent();
    parent.doProjection();
  }
}
