import java.awt.*;
import java.awt.geom.*;

/**
 * <b>Programm:</b> WaveGradient<br>
 * <b>Copyright:</b> 2002 Andreas Gohr, Frank Schubert<br>
 * <b>License:</b> GPL2 or higher<br>
 * <br>
 * <b>Info:</b> Vertical projection class, uses a GeneralPath that describes the
 *  vertical projection.
 */

public class ProjectionVertical extends Canvas { 
  MonoWave _mw = null;
  /**
   * Constructor
   */
  public ProjectionVertical(MonoWave mw) {
    _mw = mw;
  }
  
  /**
   * offscreen rendering
   */
  public void offpaint(Graphics g) {
    Graphics2D g2 = (Graphics2D) g;

    //set up background
    g2.setRenderingHint( RenderingHints.KEY_ANTIALIASING,
                         RenderingHints.VALUE_ANTIALIAS_ON);
    g2.setBackground(Color.black);
    g2.clearRect(0, 0, getWidth(), getHeight());
    g2.setPaint(Color.red);

    //Scale to Width
    g2.translate(getWidth()/2,0);
    g2.scale(getWidth()/2,1);
    g2.setStroke(new BasicStroke(0.05f));    
    g2.draw(_mw.getVerticalPath());
  }
  
  /**
   * Overwrites original update and removes the screnn clearing as we use
   * doublebuffering by using offpaint()
   */
  public void update(Graphics g){
    paint(g);
  }
  
  /**
   * initializes the offscreenbuffer, calls offpaint() and paints the buffer
   */
  public void paint(Graphics g){
    Image buffer;
    buffer =  createImage(getWidth(),getHeight());
    offpaint(buffer.getGraphics());
    g.drawImage(buffer,0,0,this);
  }
}
