import java.awt.*;
import java.awt.image.*;
import java.awt.geom.*;
import javax.swing.*;

/**
 * <b>Programm:</b> WaveGradient<br>
 * <b>Copyright:</b> 2002 Andreas Gohr, Frank Schubert<br>
 * <b>License:</b> GPL2 or higher<br>
 * <br>
 * <b>Info:</b> WaveGradientContext class, calculates the raster and
 * values for the horizontal and the vertical projection.
 */

public class WaveGradientContext implements PaintContext{
  MonoWave _mw;
  Color _color;
  AffineTransform _trans;

  /**
   * Constructor
   */
  public WaveGradientContext(MonoWave mw,Color color,AffineTransform trans){
    _mw = mw;
    _color = color;
    _trans = trans;
    _mw.setVerticalPath(new GeneralPath());
    _mw.setHorizontalPath(new GeneralPath());
  }


  public void dispose(){}
  
  /**
   * returns the calculated wave raster
   */
  public Raster getRaster(int x, int y, int w, int h){
    WritableRaster raster = getColorModel().createCompatibleWritableRaster(w,h);
    double[] vals = new double[4*w*h];
    int base;
    Point2D p2d;
        
    double A = _mw.getAmplitude();

    for (int i=0; i<h; i++){
      for (int j=0; j<w; j++){
        base = 4 * (i * w + j);
        
        //transformation from "outside"
        p2d = new Point2D.Double(i+y,j+x);
        p2d = _trans.transform(p2d,null);

        //rotation:
        AffineTransform mytrans = new AffineTransform();
        mytrans.rotate(-(_mw.getRotationRad()));
        p2d = mytrans.transform(p2d,null);

        double akt = _mw.getPsi( p2d.getX(), p2d.getY() );
        akt = (akt/A)*_mw.getRatio(); //amplitude between -1.0 and 1.0
   
        vals[base+0]= _color.getRed();
	      vals[base+1]= _color.getGreen();
        vals[base+2]= _color.getBlue();
        /* calculate alpha value */
        vals[base+3]= ((255.0*akt)+255)/2;
        
        /* at real 0,0 we use moveTo */
        if((i+y)==0 && (j+x)==0){
          _mw.getVerticalPath().moveTo((float) akt,(float) 0);
          _mw.getHorizontalPath().moveTo((float) 0,(float) akt);
        /* otherwise lineTo */
        }else

        /* projection of top line */
        if((i+y)==0){
          _mw.getHorizontalPath().lineTo((float) j+x,(float) akt);         
        }
        /* projection of left line */
        if((j+x)==0){
          _mw.getVerticalPath().lineTo((float) akt,(float) i+y);
        }

      }
    }
    raster.setPixels(0,0,w,h,vals);    
    return (raster);
  }
			
  public ColorModel getColorModel(){
    return (ColorModel.getRGBdefault());
  }

}
