import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
import javax.swing.event.*;

/**
 * <b>Programm:</b> WaveGradient<br>
 * <b>Copyright:</b> 2002 Andreas Gohr, Frank Schubert<br>
 * <b>License:</b> GPL2 or higher<br>
 * <br>
 * <b>Info:</b> Main class, implements all needed listeners
 */
public class WaveGradientMain extends ManagedPanel
                           implements ChangeListener,
                                      MouseInputListener{
  MonoWave _mw = null;
  ProjectionVertical _pv = null;
  ProjectionHorizontal _ph = null;
  Painting _p = null;
  Point _last = null;
  
  /**
   * Constructor
   */
  public WaveGradientMain(){
    _last = new Point(0,0); 
    // MonoWave(Amplitude,Frequency,WaveLength)
    _mw = new MonoWave(20.0,0.5,2.0);


    _p = new Painting(_mw);
    _p.addMouseListener(this);
    _p.addMouseMotionListener(this);
    this.addComponent(_p,1,1,1,1,2,1);
    
    _pv = new ProjectionVertical(_mw);
    _pv.setSize(50,50);
    this.addComponent(_pv,0,1,1,1,0,0);
    
    
    _ph = new ProjectionHorizontal(_mw);
    _ph.setSize(50,50);
    this.addComponent(_ph,1,0,1,1,0,0);

    InputPanel ip = new InputPanel(this,_mw);
    this.addComponent(ip,2,0,1,2,0,1);
    
  }

  /**
   * force repaint of the projections
   */
  public void doProjection(){
    _pv.repaint();
    _ph.repaint();  
  }
  
  /**
   * handle statechanges of sliders
   */ 
  public void stateChanged(ChangeEvent e){
    DoubleJSlider slider = (DoubleJSlider) e.getSource();
    if (slider.getName() == "WaveLength"){
      _mw.setWaveLength(slider.getDoubleValue());
    }else if(slider.getName() == "Frequency"){
      _mw.setFrequency(slider.getDoubleValue());
    }else if(slider.getName() == "Amplitude"){
      _mw.setAmplitude(slider.getDoubleValue());
    }else if(slider.getName() == "Phase"){
      _mw.setPhase(slider.getDoubleValue());
    }
    _p.repaint();  
  }
  
  /**
   * handles mousedrag operations
   */
  public void mouseDragged(MouseEvent e){
    double dx;
    dx = _last.getX()-e.getX();
    _last.setLocation(e.getPoint());
    _mw.setRotationDeg(_mw.getRotationDeg()+dx);
    _p.repaint();
  }

  /**
   * inserts clicked point into _last for mousedragops
   */ 
  public void mousePressed(MouseEvent e){
    _last.setLocation(e.getPoint());
  }

  public void mouseReleased(MouseEvent e){}
  public void mouseMoved(MouseEvent e){}
  public void mouseEntered(MouseEvent e){}
  public void mouseExited(MouseEvent e){}
  public void mouseClicked(MouseEvent e){}
}

